@@ -223,6 +223,14 @@ class ClUpdateAction(Action):
               'method': 'Update.syncLaymanRepository(eachvar)',
               'condition': lambda Get: Get('cl_update_other_set') == 'on'
              },
+             {'name': 'trim_reps',
+              'foreach': 'cl_update_sync_rep',
+              'message': __("Cleaning the history of the "
+                            "{eachvar:capitalize} repository"),
+              'method': 'Update.trimRepositories(eachvar)',
+              'condition': lambda Get: (Get('cl_update_sync_rep') and
+                                        Get('cl_update_onedepth_set') == 'on')
+              },
              {'name': 'sync_reps:regen_cache',
               'foreach': 'cl_update_sync_overlay_rep',
               'essential': False,
